@@ -25,6 +25,11 @@ _global_factory = SigOptFactory(get_default_project())
 create_run = _global_factory.create_run
 create_experiment = _global_factory.create_experiment
 get_experiment = _global_factory.get_experiment
+archive_experiment = _global_factory.archive_experiment
+unarchive_experiment = _global_factory.unarchive_experiment
+archive_run = _global_factory.archive_run
+unarchive_run = _global_factory.unarchive_run
+get_run = _global_factory.get_run
 
 
 def load_ipython_extension(ipython):
